@@ -154,7 +154,6 @@ meta_ui_tab_popup_new (const MetaTabEntry *entries,
   GList *tmp;
   GtkWidget *frame;
   int max_label_width; /* the actual max width of the labels we create */
-  AtkObject *obj;
   int max_chars_per_title; /* max chars we allow in a label */
   GdkScreen *screen;
   
@@ -205,28 +204,28 @@ meta_ui_tab_popup_new (const MetaTabEntry *entries,
       te->title = NULL;
       if (entries[i].title)
         {
-          gchar *tmp;
+          gchar *temp;
           if (entries[i].hidden)
             {
-              tmp = g_strdup_printf ("[%s]", entries[i].title);
+              temp = g_markup_printf_escaped ("[%s]", entries[i].title);
             }
           else 
             {
-              tmp = g_strdup (entries[i].title);
+              temp = g_markup_printf_escaped ("%s", entries[i].title);
             }
           
           if (entries[i].demands_attention) 
             {
               gchar *escaped, *markup;
-              escaped = g_markup_escape_text (tmp, -1);
+              escaped = g_markup_escape_text (temp, -1);
               markup = g_strdup_printf ("<b>%s</b>", escaped);
               g_free (escaped);
-              g_free (tmp);
-              tmp = markup;
+              g_free (temp);
+              temp = markup;
             }
             
-          te->title = meta_g_utf8_strndup (tmp, max_chars_per_title);
-          g_free (tmp);
+          te->title = meta_g_utf8_strndup (temp, max_chars_per_title);
+          g_free (temp);
         }
       te->widget = NULL;
       te->icon = entries[i].icon;
@@ -281,9 +280,6 @@ meta_ui_tab_popup_new (const MetaTabEntry *entries,
                      table);
 
   popup->label = gtk_label_new ("");
-  obj = gtk_widget_get_accessible (popup->label);
-  atk_object_set_role (obj, ATK_ROLE_STATUSBAR);
-  
   gtk_misc_set_padding (GTK_MISC (popup->label), 3, 3);
 
   gtk_box_pack_end (GTK_BOX (vbox), popup->label, FALSE, FALSE, 0);
